@@ -1,8 +1,8 @@
-/** 
+/**
  * @file libgcmd-deps.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,10 +27,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
-#include <libgnome/gnome-config.h>
-#include <libgnome/gnome-exec.h>
-#include <libgnomeui/gnome-app-helper.h>
-#include <libgnomeui/gnome-icon-entry.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
