@@ -1,8 +1,8 @@
-/** 
+/**
  * @file gnome-cmd-prepare-xfer-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +49,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
 {
     GnomeCmdCon *con = gnome_cmd_dir_get_connection (dialog->default_dest_dir);
     gchar *user_path = g_strstrip (g_strdup (gtk_entry_get_text (GTK_ENTRY (dialog->dest_dir_entry))));
+
     gchar *dest_path = NULL;
     gchar *dest_fn = NULL;
     gint user_path_len;
@@ -259,6 +260,7 @@ static gboolean on_dest_dir_entry_keypressed (GtkEntry *entry, GdkEventKey *even
         case GDK_F6:
             gnome_cmd_toggle_file_name_selection (dialog->dest_dir_entry);
             return TRUE;
+
         default:
             return FALSE;
     }
@@ -301,7 +303,7 @@ static void class_init (GnomeCmdPrepareXferDialogClass *klass)
 
 static void init (GnomeCmdPrepareXferDialog *dialog)
 {
-    GtkWidget *dest_dir_vbox;
+    GtkWidget *dest_dir_vbox, *dir_entry;
 
     // dest dir
     dest_dir_vbox = create_vbox (GTK_WIDGET (dialog), FALSE, 0);
@@ -309,9 +311,11 @@ static void init (GnomeCmdPrepareXferDialog *dialog)
     dialog->dest_dir_frame = create_category (GTK_WIDGET (dialog), dest_dir_vbox, "");
     gnome_cmd_dialog_add_category (GNOME_CMD_DIALOG (dialog), dialog->dest_dir_frame);
 
-    GtkWidget *dest_dir_fileentry = create_file_entry (GTK_WIDGET (dialog), "file-entry", "");
-    gtk_box_pack_start (GTK_BOX (dest_dir_vbox), dest_dir_fileentry, FALSE, FALSE, 0);
-    dialog->dest_dir_entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (dest_dir_fileentry));
+    dir_entry = gtk_entry_new ();
+    gtk_box_pack_start (GTK_BOX (dest_dir_vbox), dir_entry, TRUE, TRUE, 0);
+    dialog->dest_dir_entry = dir_entry;
+
+    gtk_widget_show_all (dialog->dest_dir_entry);
 
     g_signal_connect (dialog->dest_dir_entry, "key-press-event", G_CALLBACK (on_dest_dir_entry_keypressed), dialog);
 
@@ -328,7 +332,6 @@ static void init (GnomeCmdPrepareXferDialog *dialog)
     dialog->right_vbox_frame = create_category (GTK_WIDGET (dialog), dialog->right_vbox, "");
     gtk_container_add (GTK_CONTAINER (options_hbox), dialog->right_vbox_frame);
 
-
     // buttons
     dialog->cancel_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CANCEL, NULL, NULL);
     dialog->ok_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_OK, NULL, NULL);
