@@ -2,7 +2,7 @@
  * @file gnome-cmd-file-list.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 #include <config.h>
 #include <stdio.h>
 #include <glib-object.h>
-#include <libgnomeui/gnome-popup-menu.h>
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-file-selector.h"
@@ -688,6 +687,7 @@ void GnomeCmdFileList::create_column_titles()
         gtk_widget_show (priv->column_labels[i]);
         gtk_box_pack_start (GTK_BOX (hbox), priv->column_labels[i], TRUE, TRUE, 0);
 
+        // ToDo: Replace GtkPixmap with GtkImage
         pixmap = gtk_pixmap_new (pm, bm);
         g_object_ref (pixmap);
         g_object_set_data_full (*this, "column-pixmap", pixmap, g_object_unref);
@@ -817,7 +817,7 @@ static void show_file_popup (GnomeCmdFileList *fl, GdkEventButton *event)
     g_object_ref (menu);
     g_object_set_data_full (*fl, "file_popup_menu", menu, g_object_unref);
 
-    gnome_popup_menu_do_popup (menu, nullptr, nullptr, event, fl, nullptr);
+    gtk_menu_popup (GTK_MENU (menu), nullptr, nullptr, nullptr, fl, event->button, event->time);
 }
 
 
@@ -1493,7 +1493,7 @@ static gint on_button_release (GtkWidget *widget, GdkEventButton *event, GnomeCm
             return TRUE;
         }
         else
-            if (event->button == 3)
+            if (event->button == 3 && fl->priv->right_mb_timeout_id > 0)
                 g_source_remove (fl->priv->right_mb_timeout_id);
     }
 
