@@ -2,7 +2,7 @@
  * @file gnome-cmd-file-popmenu.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #define GNOME_CMD_IS_FILE_POPMENU_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_FILE_POPMENU))
 #define GNOME_CMD_FILE_POPMENU_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_FILE_POPMENU, GnomeCmdFilePopmenuClass))
 
+#define SCRIPT_DIRECTORY PACKAGE "/" "scripts"
 
 struct GnomeCmdFilePopmenuPrivate;
 
@@ -51,3 +52,8 @@ struct GnomeCmdFilePopmenuClass
 GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl);
 
 GtkType gnome_cmd_file_popmenu_get_type ();
+
+GtkUIManager *get_file_popup_ui_manager (GnomeCmdFileList *gnomeCmdFileList);
+guint add_open_with_entries (GtkUIManager *ui_manager, GnomeCmdFileList *gnomeCmdFileList);
+guint add_action_script_entries(GtkUIManager *uiManager, GList *files);
+void add_execute_entry(GtkUIManager *ui_manager, GnomeCmdFileList *gnomeCmdFileList);
