@@ -2,7 +2,7 @@
  * @file gnome-cmd-main-menu.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,8 +54,10 @@ GtkType gnome_cmd_main_menu_get_type ();
 
 void gnome_cmd_main_menu_update_connections (GnomeCmdMainMenu *main_menu);
 
+GtkWidget *get_gnome_cmd_main_menu_bar (GnomeCmdMainMenu *main_menu);
+
 void gnome_cmd_main_menu_update_bookmarks (GnomeCmdMainMenu *main_menu);
 
 void gnome_cmd_main_menu_update_sens (GnomeCmdMainMenu *main_menu);
 
-void gnome_cmd_main_menu_add_plugin_menu (GnomeCmdMainMenu *main_menu, PluginData *data);
+void gnome_cmd_main_menu_add_plugin_menu (GnomeCmdMainMenu *main_menu, PluginData *pluginData);
