@@ -2,7 +2,7 @@
  * @file gnome-cmd-main-win.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,8 +40,6 @@
 #include "gnome-cmd-owner.h"
 #include "utils.h"
 
-#include "../pixmaps/copy_file_names.xpm"
-
 using namespace std;
 
 
@@ -74,7 +72,7 @@ enum
 
 struct GnomeCmdMainWinClass
 {
-    GnomeAppClass parent_class;
+    GtkWindowClass parent_class;
 
     void (* switch_fs) (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs);
 };
@@ -101,6 +99,7 @@ struct GnomeCmdMainWin::Private
     GtkWidget *find_btn;
 
     GtkWidget *menubar;
+    GtkWidget *menubar_new;
     GtkWidget *toolbar;
     GtkWidget *toolbar_sep;
     GtkWidget *cmdline;
@@ -120,10 +119,9 @@ struct GnomeCmdMainWin::Private
     guint key_snooper_id;
 };
 
-static GnomeAppClass *parent_class = NULL;
+static GtkWindowClass *parent_class = nullptr;
 
 static guint signals[LAST_SIGNAL] = { 0 };
-static GtkTooltips *toolbar_tooltips = NULL;
 
 static void gnome_cmd_main_win_real_switch_fs (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs);
 
@@ -193,7 +191,7 @@ inline GtkWidget *add_buttonbar_button (char *label,
 {
     GtkWidget *button = create_styled_button (label);
     g_object_set_data_full (*mw, data_label, button, g_object_unref);
-    GTK_WIDGET_UNSET_FLAGS (button, GTK_CAN_FOCUS);
+    gtk_widget_set_can_focus(button, FALSE);
 
     gtk_box_pack_start (GTK_BOX (mw->priv->buttonbar), button, TRUE, TRUE, 0);
 
@@ -228,63 +226,93 @@ static GtkWidget *create_separator (gboolean vertical)
     return box;
 }
 
-
-static void create_toolbar (GnomeCmdMainWin *mw, GnomeUIInfo *uiinfo)
+static void create_toolbar (GnomeCmdMainWin *mw)
 {
-    gint i;
+    static const GtkActionEntry entries[] =
+    {
+        { "Refresh", GTK_STOCK_REFRESH, nullptr, nullptr, _("Refresh"), (GCallback) view_refresh },
+        { "Up", GTK_STOCK_GO_UP, nullptr, nullptr, _("Up one directory"), (GCallback) view_up },
+        { "First", GTK_STOCK_GOTO_FIRST, nullptr, nullptr, _("Go to the oldest"), (GCallback) view_first },
+        { "Back", GTK_STOCK_GO_BACK, nullptr, nullptr, _("Go back"), (GCallback) view_back },
+        { "Forward", GTK_STOCK_GO_FORWARD, nullptr, nullptr, _("Go forward"), (GCallback) view_forward },
+        { "Latest", GTK_STOCK_GOTO_LAST, nullptr, nullptr, _("Go to the latest"), (GCallback) view_last },
+        { "CopyFileNames", COPYFILENAMES_STOCKID, nullptr, nullptr, _("Copy file names (SHIFT for full paths, ALT for URIs)"), (GCallback) edit_copy_fnames },
+        { "Cut", GTK_STOCK_CUT, nullptr, nullptr, _("Cut"), (GCallback) edit_cap_cut },
+        { "Copy", GTK_STOCK_COPY, nullptr, nullptr, _("Copy"), (GCallback) edit_cap_copy },
+        { "Paste", GTK_STOCK_PASTE, nullptr, nullptr, _("Paste"), (GCallback) edit_cap_paste },
+        { "Delete", GTK_STOCK_DELETE, nullptr, nullptr, _("Delete"), (GCallback) file_delete },
+        { "Edit", GTK_STOCK_EDIT,nullptr, nullptr, _("Edit (SHIFT for new document)"), (GCallback) file_edit },
+        { "Send", MAILSEND_STOCKID, nullptr, nullptr, _("Send files"), (GCallback) file_sendto },
+        { "Terminal", TERMINAL_STOCKID, nullptr, nullptr, _("Open terminal (SHIFT for root privileges)"), (GCallback) command_open_terminal__internal },
+        { "Remote", GTK_STOCK_CONNECT, nullptr, nullptr, _("Remote Server"), (GCallback) connections_open },
+        { "Drop", nullptr, nullptr, nullptr, _("Drop connection"), (GCallback) connections_close_current }
+    };
+
+    static const char *ui_description =
+    "<ui>"
+    "  <toolbar action='Toolbar'>"
+    "    <toolitem action='Refresh'/>"
+    "    <toolitem action='Up'/>"
+    "    <toolitem action='First'/>"
+    "    <toolitem action='Back'/>"
+    "    <toolitem action='Forward'/>"
+    "    <toolitem action='Latest'/>"
+    "    <separator/>"
+    "    <toolitem action='CopyFileNames'/>"
+    "    <toolitem action='Cut'/>"
+    "    <toolitem action='Copy'/>"
+    "    <toolitem action='Paste'/>"
+    "    <toolitem action='Delete'/>"
+    "    <toolitem action='Edit'/>"
+    "    <toolitem action='Send'/>"
+    "    <toolitem action='Terminal'/>"
+    "    <separator/>"
+    "    <toolitem action='Remote'/>"
+    "    <toolitem action='Drop'/>"
+    "  </toolbar>"
+    "</ui>";
+
+    GtkActionGroup *action_group;
+    GtkUIManager *ui_manager;
+    GError *error;
+
+    action_group = gtk_action_group_new ("MenuActions");
+    gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), mw);
+
+    ui_manager = gtk_ui_manager_new ();
+    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
+
+    error = NULL;
+    if (!gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, &error))
+      {
+        g_message ("building menus failed: %s", error->message);
+        g_error_free (error);
+        exit (EXIT_FAILURE);
+      }
+
+    mw->priv->toolbar = gtk_ui_manager_get_widget (ui_manager, "/Toolbar");
+    mw->priv->tb_first_btn = gtk_ui_manager_get_widget (ui_manager, "/Toolbar/First");
+    mw->priv->tb_back_btn = gtk_ui_manager_get_widget (ui_manager, "/Toolbar/Back");
+    mw->priv->tb_fwd_btn = gtk_ui_manager_get_widget (ui_manager, "/Toolbar/Forward");
+    mw->priv->tb_last_btn = gtk_ui_manager_get_widget (ui_manager, "/Toolbar/Latest");
+    mw->priv->tb_cap_cut_btn = gtk_ui_manager_get_widget (ui_manager, "/Toolbar/Cut");
+    mw->priv->tb_cap_copy_btn = gtk_ui_manager_get_widget (ui_manager, "/Toolbar/Copy");
+    mw->priv->tb_cap_paste_btn = gtk_ui_manager_get_widget (ui_manager, "/Toolbar/Paste");
+    mw->priv->tb_con_drop_btn = gtk_ui_manager_get_widget (ui_manager, "/Toolbar/Drop");
+
+    gtk_widget_set_can_focus(mw->priv->tb_first_btn, FALSE);
+    gtk_widget_set_can_focus(mw->priv->tb_back_btn, FALSE);
+    gtk_widget_set_can_focus(mw->priv->tb_fwd_btn, FALSE);
+    gtk_widget_set_can_focus(mw->priv->tb_last_btn, FALSE);
+    gtk_widget_set_can_focus(mw->priv->tb_cap_cut_btn, FALSE);
+    gtk_widget_set_can_focus(mw->priv->tb_cap_copy_btn, FALSE);
+    gtk_widget_set_can_focus(mw->priv->tb_cap_paste_btn, FALSE);
+    gtk_widget_set_can_focus(mw->priv->tb_con_drop_btn, FALSE);
 
-    mw->priv->toolbar = gtk_hbox_new (FALSE, 0);
     g_object_ref (mw->priv->toolbar);
     g_object_set_data_full (*mw, "toolbar", mw->priv->toolbar, g_object_unref);
     gtk_widget_show (mw->priv->toolbar);
 
-    if (!toolbar_tooltips)
-        toolbar_tooltips = gtk_tooltips_new ();
-
-    for (i=0; uiinfo[i].type != GNOME_APP_UI_ENDOFINFO; i++)
-    {
-        GtkWidget *w;
-
-        if (uiinfo[i].type == GNOME_APP_UI_SEPARATOR)
-            w = create_separator (TRUE);
-        else
-        {
-            GtkWidget *pixmap;
-
-            w = create_styled_button (NULL);
-            g_signal_connect (w, "clicked", G_CALLBACK (uiinfo[i].moreinfo), uiinfo[i].user_data);
-            gtk_tooltips_set_tip (toolbar_tooltips, w, uiinfo[i].hint, NULL);
-            GTK_WIDGET_UNSET_FLAGS (w, GTK_CAN_FOCUS);
-
-            pixmap = create_ui_pixmap (
-                GTK_WIDGET (mw),
-                uiinfo[i].pixmap_type, uiinfo[i].pixmap_info,
-                GTK_ICON_SIZE_LARGE_TOOLBAR);
-            if (pixmap)
-            {
-                g_object_ref (pixmap);
-                gtk_widget_show (pixmap);
-                gtk_container_add (GTK_CONTAINER (w), pixmap);
-            }
-
-            switch (i)
-            {
-                case  TOOLBAR_BTN_FIRST:      mw->priv->tb_first_btn = w;  break;
-                case  TOOLBAR_BTN_BACK:       mw->priv->tb_back_btn = w;  break;
-                case  TOOLBAR_BTN_FORWARD:    mw->priv->tb_fwd_btn = w;  break;
-                case  TOOLBAR_BTN_LAST:       mw->priv->tb_last_btn = w;  break;
-                case  TOOLBAR_BTN_CUT:        mw->priv->tb_cap_cut_btn = w;  break;
-                case  TOOLBAR_BTN_COPY:       mw->priv->tb_cap_copy_btn = w;  break;
-                case  TOOLBAR_BTN_PASTE:      mw->priv->tb_cap_paste_btn = w;  break;
-                case  TOOLBAR_BTN_DISCONNECT: mw->priv->tb_con_drop_btn = w;  break;
-                default: break;
-            }
-        }
-
-        gtk_widget_show (w);
-        gtk_box_pack_start (GTK_BOX (mw->priv->toolbar), w, FALSE, TRUE, 2);
-    }
-
     mw->priv->toolbar_sep = create_separator (FALSE);
     gtk_widget_set_sensitive (mw->priv->tb_cap_paste_btn, FALSE);
 }
@@ -346,32 +374,53 @@ static void slide_set_0_100 (GtkMenu *menu, gpointer user_data)
 
 static GtkWidget *create_slide_popup ()
 {
-    static GnomeUIInfo popmenu_uiinfo[] =
+    static const GtkActionEntry entries[] =
     {
-        GNOMEUIINFO_ITEM_NONE("100 - 0", NULL, slide_set_100_0),
-        GNOMEUIINFO_ITEM_NONE("80 - 20", NULL, slide_set_80_20),
-        GNOMEUIINFO_ITEM_NONE("60 - 40", NULL, slide_set_60_40),
-        GNOMEUIINFO_ITEM_NONE("50 - 50", NULL, slide_set_50_50),
-        GNOMEUIINFO_ITEM_NONE("40 - 60", NULL, slide_set_40_60),
-        GNOMEUIINFO_ITEM_NONE("20 - 80", NULL, slide_set_20_80),
-        GNOMEUIINFO_ITEM_NONE("0 - 100", NULL, slide_set_0_100),
-        GNOMEUIINFO_END
+        { "align_100_0", NULL, "100 - 0", nullptr, nullptr, (GCallback) slide_set_100_0},
+        { "align_80_20", NULL, "80 - 20", nullptr, nullptr, (GCallback) slide_set_80_20},
+        { "align_60_40", NULL, "60 - 40", nullptr, nullptr, (GCallback) slide_set_60_40},
+        { "align_50_50", NULL, "50 - 50", nullptr, nullptr, (GCallback) slide_set_50_50},
+        { "align_40_60", NULL, "40 - 60", nullptr, nullptr, (GCallback) slide_set_40_60},
+        { "align_20_80", NULL, "20 - 80", nullptr, nullptr, (GCallback) slide_set_20_80},
+        { "align_0_100", NULL, "0 - 100", nullptr, nullptr, (GCallback) slide_set_0_100},
     };
 
-    // Set default callback data
+    static const char *ui_description =
+    "<ui>"
+    "  <popup name='Popup'>"
+    "    <menuitem action='align_100_0'/>"
+    "    <menuitem action='align_80_20'/>"
+    "    <menuitem action='align_60_40'/>"
+    "    <menuitem action='align_50_50'/>"
+    "    <menuitem action='align_40_60'/>"
+    "    <menuitem action='align_20_80'/>"
+    "    <menuitem action='align_0_100'/>"
+    "  </popup>"
+    "</ui>";
 
-    for (guint i = 0; popmenu_uiinfo[i].type != GNOME_APP_UI_ENDOFINFO; ++i)
-        if (popmenu_uiinfo[i].type == GNOME_APP_UI_ITEM)
-            popmenu_uiinfo[i].user_data = main_win;
+    GtkActionGroup *action_group;
+    GtkUIManager *ui_manager;
+    GError *error;
+
+    action_group = gtk_action_group_new ("MenuActions");
+    gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), main_win);
+
+    ui_manager = gtk_ui_manager_new ();
+    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
+
+    error = NULL;
+    if (!gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, &error))
+      {
+        g_message ("building menus failed: %s", error->message);
+        g_error_free (error);
+        exit (EXIT_FAILURE);
+      }
+
+    GtkWidget *menu = gtk_ui_manager_get_widget (ui_manager, "/Popup");
 
-    GtkWidget *menu = gtk_menu_new ();
     g_object_ref (menu);
     g_object_set_data_full (*main_win, "slide-popup", menu, g_object_unref);
 
-    // Fill the menu
-
-    gnome_app_fill_menu (GTK_MENU_SHELL (menu), popmenu_uiinfo, NULL, FALSE, 0);
-
     return GTK_WIDGET (menu);
 }
 
@@ -605,7 +654,7 @@ void GnomeCmdMainWin::update_drop_con_button(GnomeCmdFileList *fl)
         return;
 
     GtkWidget *btn = priv->tb_con_drop_btn;
-    g_return_if_fail (GTK_IS_BUTTON (btn));
+    g_return_if_fail (GTK_IS_TOOL_BUTTON (btn));
 
     if (prev_pixmap)
     {
@@ -621,8 +670,7 @@ void GnomeCmdMainWin::update_drop_con_button(GnomeCmdFileList *fl)
         return;
     }
 
-    g_return_if_fail (toolbar_tooltips != NULL);
-    gtk_tooltips_set_tip (toolbar_tooltips, btn, gnome_cmd_con_get_close_tooltip (con), NULL);
+    gtk_widget_set_tooltip_text(btn, gnome_cmd_con_get_close_tooltip (con));
     gtk_widget_set_sensitive (btn, TRUE);
 
     if (pm)
@@ -765,7 +813,7 @@ static void class_init (GnomeCmdMainWinClass *klass)
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-    parent_class = (GnomeAppClass *) gtk_type_class (gnome_app_get_type ());
+    parent_class = (GtkWindowClass *) gtk_type_class (gtk_window_get_type ());
 
     signals[SWITCH_FS] =
         g_signal_new ("switch-fs",
@@ -805,8 +853,11 @@ static void init (GnomeCmdMainWin *mw)
     mw->priv->file_selector[LEFT] = NULL;
     mw->priv->file_selector[RIGHT] = NULL;
 
-    gnome_app_construct (GNOME_APP (mw), "gnome-commander", gcmd_owner.is_root() ? _("GNOME Commander — ROOT PRIVILEGES") :
-                                                                                   _("GNOME Commander"));
+    gtk_window_set_title (GTK_WINDOW (mw),
+                          gcmd_owner.is_root()
+                            ? _("GNOME Commander — ROOT PRIVILEGES")
+                            : _("GNOME Commander"));
+
     g_object_set_data (*mw, "main_win", mw);
     restore_size_and_pos (mw);
     gtk_window_set_policy (*mw, TRUE, TRUE, FALSE);
@@ -817,14 +868,21 @@ static void init (GnomeCmdMainWin *mw)
     gtk_widget_show (mw->priv->vbox);
 
     mw->priv->menubar = gnome_cmd_main_menu_new ();
+    mw->priv->menubar_new = get_gnome_cmd_main_menu_bar (GNOME_CMD_MAIN_MENU (mw->priv->menubar));
+
     g_object_ref (mw->priv->menubar);
+    g_object_ref (mw->priv->menubar_new);
     g_object_set_data_full (*mw, "vbox", mw->priv->menubar, g_object_unref);
+    g_object_set_data_full (*mw, "vbox", mw->priv->menubar_new, g_object_unref);
     if(gnome_cmd_data.mainmenu_visibility)
-		gtk_widget_show (mw->priv->menubar);
-    gtk_box_pack_start (GTK_BOX (mw->priv->vbox), mw->priv->menubar, FALSE, TRUE, 0);
+    {
+        gtk_widget_show (mw->priv->menubar_new);
+    }
+    gtk_box_pack_start (GTK_BOX (mw->priv->vbox), mw->priv->menubar_new, FALSE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (mw->priv->vbox), create_separator (FALSE), FALSE, TRUE, 0);
 
-    gnome_app_set_contents (GNOME_APP (mw), mw->priv->vbox);
+    gtk_widget_show (mw->priv->vbox);
+    gtk_container_add (GTK_CONTAINER (mw), mw->priv->vbox);
 
     mw->priv->paned = gnome_cmd_data.horizontal_orientation ? gtk_vpaned_new () : gtk_hpaned_new ();
 
@@ -897,7 +955,7 @@ GtkType gnome_cmd_main_win_get_type ()
             (GtkClassInitFunc) NULL
         };
 
-        mw_type = gtk_type_unique (gnome_app_get_type (), &mw_info);
+        mw_type = gtk_type_unique (gtk_window_get_type (), &mw_info);
     }
 
     return mw_type;
@@ -1239,33 +1297,9 @@ void GnomeCmdMainWin::update_bookmarks()
 
 void GnomeCmdMainWin::update_show_toolbar()
 {
-    static GnomeUIInfo toolbar_uiinfo[] =
-    {
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Refresh"), view_refresh, GTK_STOCK_REFRESH),
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Up one directory"), view_up, GTK_STOCK_GO_UP),
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Go to the oldest"), view_first, GTK_STOCK_GOTO_FIRST),
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Go back"), view_back, GTK_STOCK_GO_BACK),
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Go forward"), view_forward, GTK_STOCK_GO_FORWARD),
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Go to the latest"), view_last, GTK_STOCK_GOTO_LAST),
-        GNOMEUIINFO_SEPARATOR,
-        GNOMEUIINFO_ITEM(NULL, _("Copy file names (SHIFT for full paths, ALT for URIs)"), edit_copy_fnames, copy_file_names_xpm),
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Cut"), edit_cap_cut, GTK_STOCK_CUT),
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Copy"), edit_cap_copy, GTK_STOCK_COPY),
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Paste"), edit_cap_paste, GTK_STOCK_PASTE),
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Delete"), file_delete, GTK_STOCK_DELETE),
-        GNOMEUIINFO_SEPARATOR,
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Edit (SHIFT for new document)"), file_edit, GTK_STOCK_EDIT),
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Send files"), file_sendto, GTK_STOCK_EXECUTE),
-        GNOMEUIINFO_ITEM_FILENAME(NULL, _("Open terminal (SHIFT for root privileges)"), command_open_terminal__internal, PACKAGE_NAME G_DIR_SEPARATOR_S "terminal.svg"),
-        GNOMEUIINFO_SEPARATOR,
-        GNOMEUIINFO_ITEM_STOCK(NULL, _("Remote Server"), connections_open, GTK_STOCK_CONNECT),
-        GNOMEUIINFO_ITEM_NONE(NULL, _("Drop connection"), connections_close_current),
-        GNOMEUIINFO_END
-    };
-
     if (gnome_cmd_data.show_toolbar)
     {
-        create_toolbar (this, toolbar_uiinfo);
+        create_toolbar (this);
         gtk_box_pack_start (GTK_BOX (priv->vbox), priv->toolbar, FALSE, TRUE, 0);
         gtk_box_reorder_child (GTK_BOX (priv->vbox), priv->toolbar, 2);
         gtk_box_pack_start (GTK_BOX (priv->vbox), priv->toolbar_sep, FALSE, TRUE, 0);
@@ -1372,18 +1406,18 @@ void GnomeCmdMainWin::update_mainmenu_visibility()
 {
     if (gnome_cmd_data.mainmenu_visibility)
     {
-        gtk_widget_show (priv->menubar);
+        gtk_widget_show (priv->menubar_new);
     }
     else
     {
-        gtk_widget_hide (priv->menubar);
+        gtk_widget_hide (priv->menubar_new);
     }
 }
 
 
-void GnomeCmdMainWin::add_plugin_menu(PluginData *data)
+void GnomeCmdMainWin::add_plugin_menu(PluginData *pluginData)
 {
-    gnome_cmd_main_menu_add_plugin_menu (GNOME_CMD_MAIN_MENU (priv->menubar), data);
+    gnome_cmd_main_menu_add_plugin_menu (GNOME_CMD_MAIN_MENU (priv->menubar), pluginData);
 }
 
 
