@@ -2,7 +2,7 @@
  * @file gnome-cmd-user-actions.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
  */
 
 #include <gtk/gtk.h>
-#include <libgnome/gnome-util.h>
 #include <set>
 #include <algorithm>
 
@@ -63,6 +62,7 @@ struct _GcmdUserActionSettings
     GObject parent;
     GSettings *filter;
     GSettings *general;
+    GSettings *programs;
 };
 
 G_DEFINE_TYPE (GcmdUserActionSettings, gcmd_user_action_settings, G_TYPE_OBJECT)
@@ -77,6 +77,7 @@ static void gcmd_user_action_settings_dispose (GObject *object)
     GcmdUserActionSettings *gs = GCMD_USER_ACTIONS (object);
 
     g_clear_object (&gs->general);
+    g_clear_object (&gs->programs);
 
     G_OBJECT_CLASS (gcmd_user_action_settings_parent_class)->dispose (object);
 }
@@ -106,26 +107,27 @@ static void gcmd_user_action_settings_init (GcmdUserActionSettings *gs)
 
     global_schema = g_settings_schema_source_lookup (global_schema_source, GCMD_PREF_GENERAL, FALSE);
     gs->general = g_settings_new_full (global_schema, NULL, NULL);
+
+    global_schema = g_settings_schema_source_lookup (global_schema_source, GCMD_PREF_PROGRAMS, FALSE);
+    gs->programs = g_settings_new_full (global_schema, NULL, NULL);
 }
 
 /***********************************
  * UserActions
  ***********************************/
 
-inline GnomeCmdFileSelector *get_fs (const FileSelectorID fsID)
+GnomeCmdFileSelector *get_fs (const FileSelectorID fsID)
 {
     return main_win->fs(fsID);
 }
 
-
-inline GnomeCmdFileList *get_fl (const FileSelectorID fsID)
+GnomeCmdFileList *get_fl (const FileSelectorID fsID)
 {
     GnomeCmdFileSelector *fs = get_fs (fsID);
 
     return fs ? fs->file_list() : NULL;
 }
 
-
 // The file returned from this function is not to be unrefed
 static GnomeCmdFile *get_selected_file (const FileSelectorID fsID)
 {
@@ -728,7 +730,7 @@ void file_edit (GtkMenuItem *menuitem, gpointer not_used)
 	string cmd;
 	
 	cmd.reserve(2000);
-	if (parse_command(&cmd, command) == 0)
+	if (parse_command(&cmd, (const gchar*) command) == 0)
 	{
 	    DEBUG ('g', "Edit file command is not valid.\n");
 	    gnome_cmd_show_message (*main_win, _("No valid command given."));
@@ -864,37 +866,51 @@ void file_advrename (GtkMenuItem *menuitem, gpointer not_used)
 
 void file_sendto (GtkMenuItem *menuitem, gpointer not_used)
 {
-    gchar        *command = NULL;
-    string        dir_path;
-    string        cmd;
+    string commandString;
+    commandString.reserve(2000);
 
-    command = g_strdup (gnome_cmd_data.options.sendto);
-    g_return_if_fail (command != NULL);
-    
-    cmd.reserve(2000);
-
-    if (parse_command(&cmd, g_strdup(gnome_cmd_data.options.sendto)) == 0)
+    if (parse_command(&commandString, (const gchar*) gnome_cmd_data.options.sendto) == 0)
     {
-	DEBUG ('g', "Sendto command is not valid.\n");
-	gnome_cmd_show_message (*main_win, _("No valid command given."));
-	return;
+	    DEBUG ('g', "Sendto command is not valid.\n");
+	    gnome_cmd_show_message (*main_win, _("No valid command given."));
+	    return;
     }
     else
     {
-    GnomeCmdDir *dir = NULL;
-	gint     argc;
-	gchar  **argv  = NULL;
-	GError  *error = NULL;
-	DEBUG ('g', "Invoking 'Send files': %s\n", cmd.c_str());
-	g_shell_parse_argv (cmd.c_str(), &argc, &argv, NULL);
-	if (!g_spawn_async (gnome_cmd_dir_is_local (dir) ? dir_path.c_str() : NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &error))
-	    gnome_cmd_error_message (_("Unable to execute command."), error);
-	g_free (command);
-	g_strfreev (argv);
+        gint     argc;
+        gchar  **argv  = nullptr;
+        GError  *error = nullptr;
+
+        eventually_warn_if_xdg_email_is_used();
+
+        DEBUG ('g', "Invoking 'Send files': %s\n", commandString.c_str());
+        g_shell_parse_argv (commandString.c_str(), &argc, &argv, nullptr);
+
+        if (!g_spawn_async (nullptr, argv, nullptr, G_SPAWN_SEARCH_PATH, nullptr, nullptr, nullptr, &error))
+        {
+            gnome_cmd_error_message (_("Unable to execute command."), error);
+        }
+        g_strfreev (argv);
     }
 }
 
 
+void eventually_warn_if_xdg_email_is_used()
+{
+    auto fileList = get_fl (ACTIVE);
+    GList *selectedFileList = fileList->get_selected_files();
+    auto currentSendToString = g_settings_get_string (gcmd_user_actions.settings->programs, GCMD_SETTINGS_SENDTO_CMD);
+
+    if ((g_strcmp0(currentSendToString, "xdg-email --attach %s") == 0)
+        && g_list_length(selectedFileList) > 1)
+    {
+        gnome_cmd_show_message (*main_win, _("Warning"), _("The default send-to command only supports one selected file at a time. You can change the command in the program options."));
+    }
+    g_list_free(selectedFileList);
+    g_free(currentSendToString);
+}
+
+
 void file_properties (GtkMenuItem *menuitem, gpointer not_used)
 {
     gnome_cmd_file_list_show_properties_dialog (get_fl (ACTIVE));
@@ -1060,13 +1076,18 @@ void edit_filter (GtkMenuItem *menuitem, gpointer not_used)
 }
 
 
-void edit_copy_fnames (GtkMenuItem *menuitem, gpointer not_used)
+void edit_copy_fnames (GtkMenuItem *menuitem, gpointer fileList)
 {
     GdkModifierType mask;
+    GnomeCmdFileList *fl;
 
-    gdk_window_get_pointer (NULL, NULL, NULL, &mask);
+    gdk_window_get_pointer (nullptr, nullptr, nullptr, &mask);
 
-    GnomeCmdFileList *fl = get_fl (ACTIVE);
+    if (!GNOME_CMD_IS_FILE_LIST(fileList) || (GnomeCmdFileList*) fileList == nullptr)
+    {
+        fileList = get_fl (ACTIVE);
+    }
+    fl = (GnomeCmdFileList*) fileList;
     GList *sfl = fl->get_selected_files();
     sfl = fl->sort_selection(sfl);
 
@@ -1124,7 +1145,7 @@ void command_execute (GtkMenuItem *menuitem, gpointer command)
     }
 
     cmd.reserve(2000);
-    if (parse_command(&cmd, (gchar*) command) == 0)
+    if (parse_command(&cmd, (const gchar*) command) == 0)
     {
 	DEBUG ('g', "Command is not valid.\n");
 	gnome_cmd_show_message (*main_win, _("No valid command given."));
@@ -1410,47 +1431,48 @@ void mark_compare_directories (GtkMenuItem *menuitem, gpointer not_used)
 /* Changing of GSettings here will trigger functions in gnome-cmd-data.cc */
 /* ********************************************************************** */
 
-void view_conbuttons (GtkMenuItem *menuitem, gpointer not_used)
+void view_conbuttons (GtkToggleAction *toggleAction, gpointer not_used)
 {
     if (!GTK_WIDGET_REALIZED (main_win)) return;
 
-    GtkCheckMenuItem *checkitem = (GtkCheckMenuItem *) menuitem;
-    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_DEVBUTTONS, checkitem->active);
+    auto active = gtk_toggle_action_get_active(toggleAction);
+    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_DEVBUTTONS, active);
 }
 
 
-void view_devlist (GtkMenuItem *menuitem, gpointer not_used)
+void view_devlist (GtkToggleAction *toggleAction, gpointer not_used)
 {
     if (!GTK_WIDGET_REALIZED (main_win)) return;
 
-    GtkCheckMenuItem *checkitem = (GtkCheckMenuItem *) menuitem;
-    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_DEVLIST, checkitem->active);
+    auto active = gtk_toggle_action_get_active(toggleAction);
+    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_DEVLIST, active);
 }
 
 
-void view_toolbar (GtkMenuItem *menuitem, gpointer not_used)
+void view_toolbar (GtkToggleAction *toggleAction, gpointer not_used)
 {
     if (!GTK_WIDGET_REALIZED (main_win)) return;
-    GtkCheckMenuItem *checkitem = (GtkCheckMenuItem *) menuitem;
-    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_TOOLBAR, checkitem->active);
+
+    auto active = gtk_toggle_action_get_active(toggleAction);
+    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_TOOLBAR, active);
 }
 
 
-void view_buttonbar (GtkMenuItem *menuitem, gpointer not_used)
+void view_buttonbar (GtkToggleAction *toggleAction, gpointer not_used)
 {
     if (!GTK_WIDGET_REALIZED (main_win)) return;
 
-    GtkCheckMenuItem *checkitem = (GtkCheckMenuItem *) menuitem;
-    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_BUTTONBAR, checkitem->active);
+    auto active = gtk_toggle_action_get_active(toggleAction);
+    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_BUTTONBAR, active);
 }
 
 
-void view_cmdline (GtkMenuItem *menuitem, gpointer not_used)
+void view_cmdline (GtkToggleAction *toggleAction, gpointer not_used)
 {
     if (!GTK_WIDGET_REALIZED (main_win)) return;
 
-    GtkCheckMenuItem *checkitem = (GtkCheckMenuItem *) menuitem;
-    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_CMDLINE, checkitem->active);
+    auto active = gtk_toggle_action_get_active(toggleAction);
+    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_CMDLINE, active);
 }
 
 
@@ -1460,29 +1482,30 @@ void view_dir_history (GtkMenuItem *menuitem, gpointer not_used)
 }
 
 
-void view_hidden_files (GtkMenuItem *menuitem, gpointer not_used)
+void view_hidden_files (GtkToggleAction *toggleAction, gpointer not_used)
 {
     if (!GTK_WIDGET_REALIZED (main_win)) return;
 
-    GtkCheckMenuItem *checkitem = (GtkCheckMenuItem *) menuitem;
-    g_settings_set_boolean (gcmd_user_actions.settings->filter, GCMD_SETTINGS_FILTER_DOTFILE, !checkitem->active);
+    auto active = gtk_toggle_action_get_active(toggleAction);
+    g_settings_set_boolean (gcmd_user_actions.settings->filter, GCMD_SETTINGS_FILTER_DOTFILE, !active);
 }
 
 
-void view_backup_files (GtkMenuItem *menuitem, gpointer not_used)
+void view_backup_files (GtkToggleAction *toggleAction, gpointer not_used)
 {
     if (!GTK_WIDGET_REALIZED (main_win)) return;
 
-    GtkCheckMenuItem *checkitem = (GtkCheckMenuItem *) menuitem;
-    g_settings_set_boolean (gcmd_user_actions.settings->filter, GCMD_SETTINGS_FILTER_BACKUP, !checkitem->active);
+    auto active = gtk_toggle_action_get_active(toggleAction);
+    g_settings_set_boolean (gcmd_user_actions.settings->filter, GCMD_SETTINGS_FILTER_BACKUP, !active);
 }
 
 
-void view_horizontal_orientation (GtkMenuItem *menuitem, gpointer not_used)
+void view_horizontal_orientation (GtkToggleAction *toggleAction, gpointer not_used)
 {
     if (!GTK_WIDGET_REALIZED (main_win)) return;
-    GtkCheckMenuItem *checkitem = (GtkCheckMenuItem *) menuitem;
-    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_HORIZONTAL_ORIENTATION, checkitem->active);
+
+    auto active = gtk_toggle_action_get_active(toggleAction);
+    g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_HORIZONTAL_ORIENTATION, active);
 }
 
 void view_step_up (GtkMenuItem *menuitem, gpointer not_used)
@@ -1547,7 +1570,9 @@ void view_last (GtkMenuItem *menuitem, gpointer not_used)
 
 void view_refresh (GtkMenuItem *menuitem, gpointer file_list)
 {
-    GnomeCmdFileList *fl = file_list ? GNOME_CMD_FILE_LIST (file_list) : get_fl (ACTIVE);
+    GnomeCmdFileList *fl = GNOME_CMD_IS_FILE_LIST(file_list)
+        ? GNOME_CMD_FILE_LIST (file_list)
+        : get_fl (ACTIVE);
     fl->reload();
 }
 
@@ -1933,7 +1958,7 @@ void help_web (GtkMenuItem *menuitem, gpointer not_used)
 {
     GError *error = NULL;
 
-    if (!gtk_show_uri (NULL, "http://gcmd.github.io/", GDK_CURRENT_TIME, &error))
+    if (!gtk_show_uri (NULL, "https://gcmd.github.io/", GDK_CURRENT_TIME, &error))
         gnome_cmd_error_message (_("There was an error opening home page."), error);
 }
 
@@ -1967,7 +1992,7 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
 
     static const gchar copyright[] = "Copyright \xc2\xa9 2001-2006 Marcus Bjurman\n"
                                      "Copyright \xc2\xa9 2007-2012 Piotr Eljasiak\n"
-                                     "Copyright \xc2\xa9 2013-2019 Uwe Scholz";
+                                     "Copyright \xc2\xa9 2013-2020 Uwe Scholz";
 
     static const gchar comments[] = N_("A fast and powerful file manager for the GNOME desktop");
 
@@ -1999,7 +2024,7 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
                            "documenters", documenters,
                            "logo-icon-name", PACKAGE_NAME,
                            "translator-credits", _("translator-credits"),
-                           "website", "http://gcmd.github.io",
+                           "website", "https://gcmd.github.io",
                            "website-label", "GNOME Commander Website",
                            NULL);
 
@@ -2025,7 +2050,7 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
  * \param[out] cmd A string with parsed symbols listed above
  * \returns Length of the cmd string
  */
-int parse_command(string *cmd, gchar *command)
+int parse_command(string *cmd, const gchar *command)
 {
     gboolean percent = FALSE;
     gboolean blcheck = FALSE;
@@ -2045,7 +2070,7 @@ int parse_command(string *cmd, gchar *command)
     cmdcap = cmd->capacity();
     cmdlen = cmd->length();
 
-    for (const char *s=(const char *) command; *s; ++s)
+    for (auto s = command; *s; ++s)
     {
         if (!percent)
         {
