@@ -2,7 +2,7 @@
  * @file gnome-cmd-user-actions.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,8 @@
 #include "gnome-cmd-main-win.h"
 #include "dict.h"
 
-#define GNOME_CMD_USER_ACTION(f)   void f(GtkMenuItem *menuitem=NULL, gpointer user_data=NULL)
+#define GNOME_CMD_USER_ACTION(f)       void f(GtkMenuItem *menuitem=NULL, gpointer user_data=NULL)
+#define GNOME_CMD_USER_ACTION_TGL(f)   void f(GtkToggleAction *toggleAction=nullptr, gpointer user_data=nullptr)
 
 #define USER_ACTION_SETTINGS (gcmd_user_action_settings_get_type ())
 G_DECLARE_FINAL_TYPE (GcmdUserActionSettings, gcmd_user_action_settings, GCMD, USER_ACTIONS, GObject)
@@ -135,6 +136,8 @@ inline GdkEventKey str2key(gchar *s)
     return str2key(s, event);
 }
 
+GnomeCmdFileSelector *get_fs (const FileSelectorID fsID);
+GnomeCmdFileList     *get_fl (const FileSelectorID fsID);
 
 class GnomeCmdUserActions
 {
@@ -209,6 +212,9 @@ inline gboolean GnomeCmdUserActions::register_action(guint keyval, const gchar *
     return register_action(0, keyval, action_name_argument, user_data);
 }
 
+int parse_command(string *cmd, const gchar *command);
+
+void eventually_warn_if_xdg_email_is_used();
 
 extern GnomeCmdUserActions gcmd_user_actions;
 
@@ -272,14 +278,14 @@ GNOME_CMD_USER_ACTION(command_open_terminal_as_root);
 GNOME_CMD_USER_ACTION(command_root_mode);
 
 /************** View Menu **************/
-GNOME_CMD_USER_ACTION(view_conbuttons);
-GNOME_CMD_USER_ACTION(view_devlist);
-GNOME_CMD_USER_ACTION(view_toolbar);
-GNOME_CMD_USER_ACTION(view_buttonbar);
-GNOME_CMD_USER_ACTION(view_cmdline);
+GNOME_CMD_USER_ACTION_TGL(view_conbuttons);
+GNOME_CMD_USER_ACTION_TGL(view_devlist);
+GNOME_CMD_USER_ACTION_TGL(view_toolbar);
+GNOME_CMD_USER_ACTION_TGL(view_buttonbar);
+GNOME_CMD_USER_ACTION_TGL(view_cmdline);
 GNOME_CMD_USER_ACTION(view_dir_history);
-GNOME_CMD_USER_ACTION(view_hidden_files);
-GNOME_CMD_USER_ACTION(view_backup_files);
+GNOME_CMD_USER_ACTION_TGL(view_hidden_files);
+GNOME_CMD_USER_ACTION_TGL(view_backup_files);
 GNOME_CMD_USER_ACTION(view_up);
 GNOME_CMD_USER_ACTION(view_first);
 GNOME_CMD_USER_ACTION(view_back);
@@ -304,7 +310,7 @@ GNOME_CMD_USER_ACTION(view_next_tab);
 GNOME_CMD_USER_ACTION(view_in_new_tab);
 GNOME_CMD_USER_ACTION(view_in_inactive_tab);
 GNOME_CMD_USER_ACTION(view_toggle_tab_lock);
-GNOME_CMD_USER_ACTION(view_horizontal_orientation);
+GNOME_CMD_USER_ACTION_TGL(view_horizontal_orientation);
 GNOME_CMD_USER_ACTION(view_main_menu);
 GNOME_CMD_USER_ACTION(view_step_up);
 GNOME_CMD_USER_ACTION(view_step_down);
