@@ -2,7 +2,7 @@
  * @file imageloader.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -140,6 +140,8 @@ void IMAGE_init ()
 
         g_free (path);
     }
+
+    register_gnome_commander_stock_icons ();
 }
 
 
@@ -487,3 +489,98 @@ void IMAGE_free ()
         pixmaps[i] = nullptr;
     }
 }
+
+static struct
+{
+    const gchar *filename;
+    const gchar *stock_id;
+} stock_icons[] =
+{
+    { PIXMAPS_DIR G_DIR_SEPARATOR_S "copy_file_names.xpm",    COPYFILENAMES_STOCKID },
+    { PIXMAPS_DIR G_DIR_SEPARATOR_S "exec_wheel.xpm",         EXEC_WHEEL_STOCKID},
+    { PIXMAPS_DIR G_DIR_SEPARATOR_S "mail-send.png",          MAILSEND_STOCKID },
+    { PIXMAPS_DIR G_DIR_SEPARATOR_S "terminal.svg",           TERMINAL_STOCKID },
+    { PIXMAPS_DIR G_DIR_SEPARATOR_S "rotate-90-16.xpm",       ROTATE_90_STOCKID },
+    { PIXMAPS_DIR G_DIR_SEPARATOR_S "rotate-270-16.xpm",      ROTATE_270_STOCKID },
+    { PIXMAPS_DIR G_DIR_SEPARATOR_S "rotate-180-16.xpm",      ROTATE_180_STOCKID },
+    { PIXMAPS_DIR G_DIR_SEPARATOR_S "flip-vertical-16.xpm",   FLIP_VERTICAL_STOCKID },
+    { PIXMAPS_DIR G_DIR_SEPARATOR_S "flip-horizontal-16.xpm", FLIP_HORIZONTAL_STOCKID },
+    { PIXMAPS_DIR G_DIR_SEPARATOR_S FILETYPEICONS_FOLDER G_DIR_SEPARATOR_S "file_type_dir.xpm",     FILETYPEDIR_STOCKID},
+    { PIXMAPS_DIR G_DIR_SEPARATOR_S FILETYPEICONS_FOLDER G_DIR_SEPARATOR_S "file_type_regular.xpm", FILETYPEREGULARFILE_STOCKID},
+};
+
+static gint n_stock_icons = G_N_ELEMENTS (stock_icons);
+
+void register_gnome_commander_stock_icons (void)
+{
+    GtkIconFactory *icon_factory;
+    GtkIconSet *icon_set;
+    GtkIconSource *icon_source;
+    gint i;
+
+    icon_factory = gtk_icon_factory_new ();
+
+    for (i = 0; i < n_stock_icons; i++)
+       {
+           icon_set = gtk_icon_set_new ();
+           icon_source = gtk_icon_source_new ();
+           gtk_icon_source_set_filename (icon_source, stock_icons[i].filename);
+           gtk_icon_set_add_source (icon_set, icon_source);
+           gtk_icon_source_free (icon_source);
+           gtk_icon_factory_add (icon_factory, stock_icons[i].stock_id, icon_set);
+           gtk_icon_set_unref (icon_set);
+       }
+
+    gtk_icon_factory_add_default (icon_factory);
+
+    g_object_unref (icon_factory);
+}
+
+/**
+ * This method registers stock icon with a given application name and its absolute path name.
+ * Returns the stockId for the registered stock icon. Has to be g_free'ed.
+ */
+char* register_application_stock_icon(const char* applicationName, const char* defaultAppIconPath)
+{
+    // First, create the stockId string
+    g_return_val_if_fail (applicationName, nullptr);
+    g_return_val_if_fail (defaultAppIconPath, nullptr);
+
+    if( access( defaultAppIconPath, F_OK ) == -1 )
+    {
+        // icon doesn't exist
+        return nullptr;
+    }
+
+    // add "gnome-commander-" in front of the stockId to prevent doubled id's
+    char* stockId = g_strdup_printf("%s%s", PACKAGE "-", applicationName);
+
+    // is the icon already loaded into the default icon factory?
+    auto  gtkIconSet = gtk_icon_factory_lookup_default (stockId);
+    if (gtkIconSet != nullptr)
+    {
+        // don't need to record the icon anymore
+        return stockId;
+    }
+
+    // Now register the stock icon with the created stockId
+    GtkIconFactory *icon_factory;
+    GtkIconSet *icon_set;
+    GtkIconSource *icon_source;
+
+    icon_factory = gtk_icon_factory_new ();
+
+    icon_set = gtk_icon_set_new ();
+    icon_source = gtk_icon_source_new ();
+    gtk_icon_source_set_filename (icon_source, defaultAppIconPath);
+    gtk_icon_set_add_source (icon_set, icon_source);
+    gtk_icon_source_free (icon_source);
+    gtk_icon_factory_add (icon_factory, stockId, icon_set);
+    gtk_icon_set_unref (icon_set);
+
+    gtk_icon_factory_add_default (icon_factory);
+
+    g_object_unref (icon_factory);
+
+    return stockId;
+}
\ No newline at end of file
