@@ -1,8 +1,8 @@
-/** 
+/**
  * @file imageloader.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,20 @@
 
 #pragma once
 
+#define FILETYPEICONS_FOLDER        "file-type-icons"
+
+#define COPYFILENAMES_STOCKID       "gnome-commander-copy-file-names"
+#define EXEC_WHEEL_STOCKID          "gnome-commander-exec_wheel"
+#define FILETYPEDIR_STOCKID         "gnome-commander-file-type-dir"
+#define FILETYPEREGULARFILE_STOCKID "gnome-commander-file-type-regular-file"
+#define MAILSEND_STOCKID            "gnome-commander-mail-send"
+#define TERMINAL_STOCKID            "gnome-commander-terminal"
+#define ROTATE_90_STOCKID           "gnome-commander-rotate-90"
+#define ROTATE_270_STOCKID          "gnome-commander-rotate-270"
+#define ROTATE_180_STOCKID          "gnome-commander-rotate-180"
+#define FLIP_VERTICAL_STOCKID       "gnome-commander-flip-vertical"
+#define FLIP_HORIZONTAL_STOCKID     "gnome-commander-flip-horizontal"
+
 #include "gnome-cmd-pixmap.h"
 
 /**
@@ -78,3 +92,7 @@ gboolean IMAGE_get_pixmap_and_mask (GnomeVFSFileType type,
                                     GdkBitmap **mask);
 
 void IMAGE_clear_mime_cache ();
+
+void register_gnome_commander_stock_icons (void);
+
+char* register_application_stock_icon(const char* openWithDefaultLabel, const char* defaultAppIconPath);
\ No newline at end of file
