@@ -2,7 +2,7 @@
  * @file gnome-cmd-tags-exiv2.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,9 +31,7 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #ifdef HAVE_EXIV2
-#include <exiv2/exif.hpp>
-#include <exiv2/image.hpp>
-#include <exiv2/error.hpp>
+#include <exiv2/exiv2.hpp>
 #endif
 
 using namespace std;
