@@ -2,7 +2,7 @@
  * @file utils.h 
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2019 Uwe Scholz\n
+ * @copyright (C) 2013-2020 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -207,11 +207,6 @@ gboolean app_needs_terminal (GnomeCmdFile *f);
 gchar *get_temp_download_filepath (const gchar *fname);
 void remove_temp_download_dir ();
 
-GtkWidget *create_ui_pixmap (GtkWidget *window,
-                             GnomeUIPixmapType pixmap_type,
-                             gconstpointer pixmap_info,
-                             GtkIconSize size);
-
 gchar *unix_to_unc (const gchar *path);
 GdkColor *gdk_color_new (gushort r, gushort g, gushort b);
 GList *file_list_to_uri_list (GList *files);
@@ -277,12 +272,6 @@ inline void gnome_cmd_error_message (const gchar *title, GError *error)
 }
 
 
-// Insert an item with an inline xpm icon and a user data pointer
-#define GNOMEUIINFO_ITEM_FILENAME(label, tooltip, callback, filename) \
-    { GNOME_APP_UI_ITEM, label, tooltip, (gpointer) callback, NULL, NULL, \
-        GNOME_APP_PIXMAP_FILENAME, filename, 0, (GdkModifierType) 0, NULL }
-
-
 inline std::string truncate(const std::string &s, guint n=100)
 {
     if (s.size()<=n)
